@@ -1,4 +1,4 @@
-/*  $Id: archive.c 9658 2014-08-28 18:59:18Z iulius $
+/*  $Id: archive.c 10342 2019-05-30 14:18:48Z iulius $
 **
 **  Read batchfiles on standard input and archive them.
 */
@@ -462,7 +462,7 @@ main(int argc, char *argv[])
 
     /* Write the rest of stdin to the spool file. */
     status = 0;
-    if (fprintf(spool, "%s\n", line) == EOF) {
+    if (fprintf(spool, "%s\n", line != NULL ? line : "") == EOF) {
         syswarn("cannot start spool");
         status = 1;
     }
