@@ -1,60 +1,57 @@
-/*  $Revision: 1.5 $
+/*  $Id: filechan.c 7585 2006-11-21 09:37:51Z eagle $
 **
 **  An InterNetNews channel process that splits a funnel entry into
 **  separate files.  Originally from Robert Elz <kre@munnari.oz.au>.
 */
-#include <stdio.h>
-#include <sys/types.h>
-#include "configdata.h"
+
+#include "config.h"
 #include "clibrary.h"
-#include <sys/stat.h>
 #include <errno.h>
 #include <fcntl.h>
-#include <sys/file.h>
-#include "paths.h"
-#include "libinn.h"
-#include "macros.h"
-#include <syslog.h>  
+#include <sys/stat.h>
 
-extern void	MAPread();
-extern char	*MAPname();
+#include "inn/innconf.h"
+#include "inn/messages.h"
+#include "inn/libinn.h"
+#include "inn/paths.h"
+
+#include "map.h"
 
 int
-main(ac, av)
-    int			ac;
-    char		*av[];
+main(int ac, char *av[])
 {
     char		buff[2048];
-    register char	*p;
-    register char	*next;
-    register int	i;
-    register int	fd;
+    char                *p;
+    char                *next;
+    int                 i;
+    int                 fd;
     int			Fields;
-    STRING		Directory;
-    BOOL		Map;
+    const char		*Directory;
+    bool		Map;
     FILE		*F;
     struct stat		Sb;
-    UID_T		uid;
-    GID_T		gid;
-    UID_T		myuid;
+    uid_t		uid;
+    gid_t		gid;
+    uid_t		myuid;
 
-    /* First thing, set up logging and our identity. */
-    openlog("filechan", L_OPENLOG_FLAGS | LOG_PID, LOG_INN_PROG);           
+    /* First thing, set up our identity. */
+    message_program_name = "filechan";
 
     /* Set defaults. */
-    if (ReadInnConf() < 0) exit(1);
+    if (!innconf_read(NULL))
+        exit(1);
     Fields = 1;
     Directory = innconf->pathoutgoing;
-    Map = FALSE;
+    Map = false;
     myuid = geteuid();
-    (void)umask(NEWSUMASK);
+    umask(NEWSUMASK);
 
     /* Parse JCL. */
     while ((i = getopt(ac, av, "d:f:m:p:")) != EOF)
 	switch (i) {
 	default:
-	    (void)fprintf(stderr, "Usage error.\n");
-	    exit(1);
+            die("usage error");
+            break;
 	case 'd':
 	    Directory = optarg;
 	    break;
@@ -62,35 +59,23 @@ main(ac, av)
 	    Fields = atoi(optarg);
 	    break;
 	case 'm':
-	    Map = TRUE;
+	    Map = true;
 	    MAPread(optarg);
 	    break;
 	case 'p':
-	    if ((F = fopen(optarg, "w")) == NULL) {
-		(void)fprintf(stderr, "filechan cant fopen %s %s\n",
-			optarg, strerror(errno));
-		exit(1);
-	    }
-	    (void)fprintf(F, "%ld\n", (long)getpid());
-	    if (ferror(F) || fclose(F) == EOF) {
-		(void)fprintf(stderr, "filechan cant fclose %s %s\n",
-			optarg, strerror(errno));
-		exit(1);
-	    }
+	    if ((F = fopen(optarg, "w")) == NULL)
+                sysdie("cannot fopen %s", optarg);
+	    fprintf(F, "%ld\n", (long)getpid());
+	    if (ferror(F) || fclose(F) == EOF)
+                sysdie("cannot fclose %s", optarg);
 	    break;
 	}
 
     /* Move, and get owner of current directory. */
-    if (chdir(Directory) < 0) {
-	(void)fprintf(stderr, "Can't chdir to %s, %s\n",
-	    Directory, strerror(errno));
-	exit(1);
-    }
-    if (stat(".", &Sb) < 0) {
-	(void)fprintf(stderr, "Can't stat %s, %s\n",
-	    Directory, strerror(errno));
-	exit(1);
-    }
+    if (chdir(Directory) < 0)
+        sysdie("cannot chdir to %s", Directory);
+    if (stat(".", &Sb) < 0)
+        sysdie("cannot stat %s", Directory);
     uid = Sb.st_uid;
     gid = Sb.st_gid;
 
@@ -126,20 +111,18 @@ main(ac, av)
 	    fd = open(p, O_CREAT | O_WRONLY | O_APPEND, BATCHFILE_MODE);
 	    if (fd >= 0) {
 		/* Try to lock it and set the ownership right. */
-		(void)LockFile(fd, TRUE);
+		inn_lock_file(fd, INN_LOCK_WRITE, true);
 		if (myuid == 0 && uid != 0)
-		    (void)chown(p, uid, gid);
+		    chown(p, uid, gid);
 
 		/* Just in case, seek to the end. */
-		(void)lseek(fd, (OFFSET_T) 0, SEEK_END);
+		lseek(fd, 0, SEEK_END);
 
 		errno = 0;
-		if (write(fd, (POINTER)buff, (SIZE_T)i) != i) {
-		    perror("write");
-		    exit(1);
-		}
+		if (write(fd, buff, i) != i)
+                    sysdie("write failed");
 
-		(void)close(fd);
+		close(fd);
 	    }
 	}
     }
