@@ -1,4 +1,4 @@
-/*  $Id: innxmit.c 9364 2011-08-21 23:23:26Z eagle $
+/*  $Id: innxmit.c 10305 2018-12-02 14:21:56Z iulius $
 **
 **  Transmit articles to remote site.
 **  Modified for NNTP streaming: 1996-01-03 Jerry Aguirre.
@@ -7,7 +7,6 @@
 #include "config.h"
 #include "clibrary.h"
 #include "portable/socket.h"
-#include "portable/time.h"
 #include <ctype.h>
 #include <errno.h>
 #include <fcntl.h>
@@ -17,6 +16,11 @@
 #include <sys/stat.h>
 #include <sys/uio.h>
 
+#ifdef HAVE_SYS_TIME_H
+# include <sys/time.h>
+#endif
+#include <time.h>
+
 /*
 **  Needed on AIX 4.1 to get fd_set and friends.
 */
@@ -91,19 +95,18 @@ static int logRejects = false ;  /* syslog the 437 responses. */
 /*
 **  Syslog formats - collected together so they remain consistent.
 */
-static char	STAT1[] =
-	"%s stats offered %lu accepted %lu refused %lu rejected %lu missing %lu accsize %.0f rejsize %.0f";
-static char	STAT2[] = "%s times user %.3f system %.3f elapsed %.3f";
-static char	GOT_BADCOMMAND[] = "%s rejected %s %s";
-static char	REJECTED[] = "%s rejected %s (%s) %s";
-static char	REJ_STREAM[] = "%s rejected (%s) %s";
-static char	CANT_CONNECT[] = "%s connect failed %s";
-static char	CANT_AUTHENTICATE[] = "%s authenticate failed %s";
-static char	IHAVE_FAIL[] = "%s ihave failed %s";
+#define STAT1 "%s stats offered %lu accepted %lu refused %lu rejected %lu missing %lu accsize %.0f rejsize %.0f"
+#define STAT2 "%s times user %.3f system %.3f elapsed %.3f"
+#define GOT_BADCOMMAND "%s rejected %s %s"
+#define REJECTED "%s rejected %s (%s) %s"
+#define REJ_STREAM "%s rejected (%s) %s"
+#define CANT_CONNECT "%s connect failed %s"
+#define CANT_AUTHENTICATE "%s authenticate failed %s"
+#define IHAVE_FAIL "%s ihave failed %s"
 
-static char	CANT_FINDIT[] = "%s can't find %s";
-static char	CANT_PARSEIT[] = "%s can't parse ID %s";
-static char	UNEXPECTED[] = "%s unexpected response code %s";
+#define CANT_FINDIT "%s can't find %s"
+#define CANT_PARSEIT "%s can't parse ID %s"
+#define UNEXPECTED "%s unexpected response code %s"
 
 /*
 **  Global variables.
@@ -145,6 +148,9 @@ static double		STATrejectedsize;
 */
 static ARTHANDLE *article_open(const char *path, const char *id);
 static void article_free(ARTHANDLE *);
+static void Usage(void) __attribute__ ((__noreturn__));
+static void RequeueRestAndExit(char *, char *) __attribute__ ((__noreturn__));
+static void ExitWithStats(int) __attribute__ ((__noreturn__));
 
 
 /*
@@ -596,7 +602,7 @@ REMsendarticle(char *Article, char *MessageID, ARTHANDLE *art) {
 	return false;
     if (HeadersFeed) {
 	struct iovec vec[3];
-	char buf[20];
+        char buf[32];
 	int iscmsg = 0;
 	int len = HeadersLen(art, &iscmsg);
 
@@ -680,9 +686,10 @@ REMsendarticle(char *Article, char *MessageID, ARTHANDLE *art) {
 */
 static char *
 GetMessageID(ARTHANDLE *art) {
-    static char	*buff;
-    static int	buffsize = 0;
-    const char	*p, *q;
+    static char		*buff = NULL;
+    static size_t	buffsize = 0; /* total size of buff */
+    size_t		buffneed;
+    const char		*p, *q;
 
     p = wire_findheader(art->data, art->len, "Message-ID", true);
     if (p == NULL)
@@ -693,12 +700,11 @@ GetMessageID(ARTHANDLE *art) {
     }
     if (q == art->data + art->len)
 	return NULL;
-    if (buffsize < q - p) {
-	if (buffsize == 0)
-	    buff = xmalloc(q - p + 1);
-	else
-            buff = xrealloc(buff, q - p + 1);
-	buffsize = q - p;
+
+    buffneed = q - p + 1; /* bytes needed, including '\0' terminator */
+    if (buffsize < buffneed) {
+        buff = xrealloc(buff, buffneed);
+        buffsize = buffneed;
     }
     memcpy(buff, p, q - p);
     buff[q - p] = '\0';
@@ -1002,7 +1008,6 @@ article_free(ARTHANDLE *article)
 
 
 int main(int ac, char *av[]) {
-    static char		SKIPPING[] = "Skipping \"%s\" --%s?\n";
     int	                i;
     char	        *p;
     ARTHANDLE		*art;
@@ -1335,7 +1340,7 @@ int main(int ac, char *av[]) {
 	/* Get the Message-ID from the article if we need to. */
 	if (MessageID == NULL) {
 	    if ((MessageID = GetMessageID(art)) == NULL) {
-                warn(SKIPPING, Article, "no message ID");
+                warn("Skipping \"%s\" -- %s?\n", Article, "no message ID");
                 article_free(art);
 		continue;
 	    }
