@@ -1,4 +1,4 @@
-/*  $Id: ninpaths.c 9928 2015-08-08 17:20:23Z iulius $
+/*  $Id: ninpaths.c 10040 2016-07-31 20:01:43Z iulius $
 **
 **  New inpaths reporting program.
 **
@@ -199,9 +199,7 @@ writedumpfile(const char *n)
 	writedump(stdout);
 	return;
     }
-#pragma GCC diagnostic ignored "-Wformat-nonliteral"
     snprintf(buf, sizeof(buf), n, time(0));
-#pragma GCC diagnostic warning "-Wformat-nonliteral"
     d=fopen(buf, "w");
     if (d) {
 	if (writedump(d)<0)
