@@ -1,4 +1,4 @@
-/*  $Id: expireover.c 8570 2009-08-17 19:05:28Z iulius $
+/*  $Id: expireover.c 10009 2016-05-05 12:39:19Z iulius $
 **
 **  Expire the overview database.
 **
@@ -201,7 +201,7 @@ main(int argc, char *argv[])
         if (!OVexpiregroup(line, &low, history))
             warn("can't expire %s", line);
         else if (lowmark != NULL && low != 0)
-            fprintf(lowmark, "%s %u\n", line, low);
+            fprintf(lowmark, "%s %d\n", line, low);
         line = QIOread(qp);
     }
     if (signalled)
