@@ -1,4 +1,4 @@
-/*  $Id: ctlinnd.c 9623 2014-03-15 22:29:46Z iulius $
+/*  $Id: ctlinnd.c 10153 2017-06-05 12:28:01Z iulius $
 **
 **  Send control messages to the InterNetNews daemon.
 */
@@ -112,6 +112,9 @@ static COMMAND	Commands[] = {
 };
 
 
+static void Usage(const char *) __attribute__ ((__noreturn__));
+static void WrongArgs(COMMAND *) __attribute__ ((__noreturn__));
+
 
 /*
 **  Print a help summary.
