@@ -1,4 +1,4 @@
-/*  $Id: inews.c 10304 2018-12-02 14:05:50Z iulius $
+/*  $Id: inews.c 10365 2020-05-10 12:58:37Z iulius $
 **
 **  Send an article (prepared by someone on the local site) to the
 **  master news server.
@@ -685,7 +685,7 @@ AppendSignature(bool UseMalloc, char *article, char *homedir, int *linesp)
     *linesp = 0;
     if (strlen(homedir) > sizeof(buff) - 14)
         die("home directory path too long");
-    sprintf(buff, "%s/.signature", homedir);
+    snprintf(buff, sizeof(buff), "%s/.signature", homedir);
     if ((F = fopen(buff, "r")) == NULL) {
 	if (errno == ENOENT)
 	    return article;
