@@ -1,4 +1,4 @@
-/*  $Id: innconfval.c 5962 2002-12-08 19:52:13Z rra $
+/*  $Id: innconfval.c 7585 2006-11-21 09:37:51Z eagle $
 **
 **  Get a config value from INN.
 */
@@ -8,7 +8,8 @@
 
 #include "inn/innconf.h"
 #include "inn/messages.h"
-#include "libinn.h"
+#include "inn/version.h"
+#include "inn/libinn.h"
 
 /*
 **  Print the INN version string with appropriate quoting.
@@ -18,16 +19,16 @@ print_version(FILE *file, enum innconf_quoting quoting)
 {
     switch (quoting) {
     case INNCONF_QUOTE_NONE:
-        fprintf(file, "%s\n", inn_version_string);
+        fprintf(file, "%s\n", INN_VERSION_STRING);
         break;
     case INNCONF_QUOTE_SHELL:
-        fprintf(file, "VERSION='%s'; export VERSION\n", inn_version_string);
+        fprintf(file, "VERSION='%s'; export VERSION\n", INN_VERSION_STRING);
         break;
     case INNCONF_QUOTE_PERL:
-        fprintf(file, "$version = '%s';\n", inn_version_string);
+        fprintf(file, "$version = '%s';\n", INN_VERSION_STRING);
         break;
     case INNCONF_QUOTE_TCL:
-        fprintf(file, "set inn_version \"%s\"\n", inn_version_string);
+        fprintf(file, "set inn_version \"%s\"\n", INN_VERSION_STRING);
         break;
     }
 }
