@@ -1,4 +1,4 @@
-/*  $Id: rnews.c 10040 2016-07-31 20:01:43Z iulius $
+/*  $Id: rnews.c 10382 2020-05-24 10:24:37Z iulius $
 **
 **  A front-end for InterNetNews.
 **
@@ -34,7 +34,10 @@ typedef struct _HEADER {
 } HEADER;
 
 
-static bool	Verbose;
+static bool     additionalUnpackers = true;
+static bool     backupBad = false;
+static bool     logDuplicates = false;
+static bool     Verbose = false;
 static const char	*InputFile = "stdin";
 static char	*UUCPHost;
 static char	*PathBadNews = NULL;
@@ -164,37 +167,49 @@ static void
 Reject(const char *article, size_t length UNUSED, const char *reason,
        const char *arg)
 {
-#if	defined(DO_RNEWS_SAVE_BAD)
     char *filename;
     FILE *F;
     int fd;
-#endif	/* defined(DO_RNEWS_SAVE_BAD) */
 
+#if __GNUC__ > 4
+# pragma GCC diagnostic ignored "-Wformat-nonliteral"
+#endif
     notice(reason, arg);
+#if __GNUC__ > 4
+# pragma GCC diagnostic warning "-Wformat-nonliteral"
+#endif
     if (Verbose) {
 	fprintf(stderr, "%s: ", InputFile);
+#if __GNUC__ > 4
+# pragma GCC diagnostic ignored "-Wformat-nonliteral"
+#endif
 	fprintf(stderr, reason, arg);
+#if __GNUC__ > 4
+# pragma GCC diagnostic warning "-Wformat-nonliteral"
+#endif
 	fprintf(stderr, " [%.40s...]\n", article);
     }
 
-#if	defined(DO_RNEWS_SAVE_BAD)
-    filename = concat(PathBadNews, "/XXXXXX", (char *) 0);
-    fd = mkstemp(filename);
-    if (fd < 0) {
-        warn("cannot create temporary file");
-        return;
+    if (backupBad) {
+        filename = concat(PathBadNews, "/XXXXXX", (char *) 0);
+        fd = mkstemp(filename);
+        if (fd < 0) {
+            warn("cannot create temporary file");
+            free(filename);
+            return;
+        }
+        F = fdopen(fd, "w");
+        if (F == NULL) {
+            warn("cannot fdopen %s", filename);
+            free(filename);
+            return;
+        }
+        if (fwrite(article, 1, length, F) != length)
+            warn("cannot fwrite to %s", filename);
+        if (fclose(F) == EOF)
+            warn("cannot close %s", filename);
+        free(filename);
     }
-    F = fdopen(fd, "w");
-    if (F == NULL) {
-        warn("cannot fdopen %s", filename);
-	return;
-    }
-    if (fwrite(article, 1, length, F) != length)
-        warn("cannot fwrite to %s", filename);
-    if (fclose(F) == EOF)
-        warn("cannot close %s", filename);
-    free(filename);
-#endif	/* defined(DO_RNEWS_SAVE_BAD) */
 }
 
 
@@ -213,12 +228,7 @@ Process(char *article, size_t artlen)
     const char		*id = NULL;
     char                *msgid;
     char		buff[SMBUF];
-#if	defined(FILE_RNEWS_LOG_DUPS)
-    FILE		*F;
-#endif	/* defined(FILE_RNEWS_LOG_DUPS) */
-#if	!defined(DONT_RNEWS_LOG_DUPS)
     char		path[40];
-#endif	/* !defined(DONT_RNEWS_LOG_DUPS) */
 
     /* Empty article? */
     if (*article == '\0')
@@ -239,13 +249,13 @@ Process(char *article, size_t artlen)
 	    id = p;
 	    continue;
 	}
-#if	!defined(DONT_RNEWS_LOG_DUPS)
-	if (IS_PATH(hp)) {
-	    strlcpy(path, p, sizeof(path));
-	    if ((q = strchr(path, '\r')) != NULL)
-		*q = '\0';
-	}
-#endif	/* !defined(DONT_RNEWS_LOG_DUPS) */
+        if (logDuplicates) {
+            if (IS_PATH(hp)) {
+                strlcpy(path, p, sizeof(path));
+                if ((q = strchr(path, '\r')) != NULL)
+                    *q = '\0';
+            }
+        }
     }
 
     /* Send the NNTP "ihave" message. */
@@ -288,17 +298,9 @@ Process(char *article, size_t artlen)
     case NNTP_CONT_IHAVE:
 	break;
     case NNTP_FAIL_IHAVE_REFUSE:
-#if	defined(SYSLOG_RNEWS_LOG_DUPS)
-	*p = '\0';
-        notice("duplicate %s %s", id, path);
-#endif	/* defined(SYSLOG_RNEWS_LOG_DUPS) */
-#if	defined(FILE_RNEWS_LOG_DUPS)
-	if ((F = fopen(INN_PATH_RNEWS_DUP_LOG, "a")) != NULL) {
-	    *p = '\0';
-	    fprintf(F, "duplicate %s %s\n", id, path);
-	    fclose(F);
-	}
-#endif	/* defined(FILE_RNEWS_LOG_DUPS) */
+        if (logDuplicates) {
+            notice("duplicate %s %s", msgid, path);
+        }
         free(wirefmt);
 	return true;
     }
@@ -484,10 +486,9 @@ ReadLine(char *p, int size, int fd)
 static bool
 UnpackOne(int *fdp, size_t *countp)
 {
-#if	defined(DO_RNEWSPROGS)
     char	path[(SMBUF * 2) + 1];
     char	*p;
-#endif	/* defined(DO_RNEWSPROGS) */
+    int         len;
     char	buff[SMBUF];
     const char *cargv[4];
     int		artsize;
@@ -575,38 +576,39 @@ UnpackOne(int *fdp, size_t *countp)
 	    continue;
 	}
 
-#if	defined(DO_RNEWSPROGS)
-        int len;
-
-	cargv[0] = UNPACK;
-	cargv[1] = NULL;
-	/* Ignore any possible leading pathnames, to avoid trouble. */
-	if ((p = strrchr(&buff[3], '/')) != NULL)
-	    p++;
-	else
-	    p = &buff[3];
-	if (strchr(INN_PATH_RNEWSPROGS, '/') == NULL) {
-	    snprintf(path, sizeof(path), "%s/%s/%s", innconf->pathbin,
-                     INN_PATH_RNEWSPROGS, p);
-	    len = strlen(innconf->pathbin) + 1 + sizeof INN_PATH_RNEWSPROGS;
-	} else {
-	    snprintf(path, sizeof(path), "%s/%s", INN_PATH_RNEWSPROGS, p);
-	    len = sizeof INN_PATH_RNEWSPROGS;
-	}
-	for (p = &path[len]; *p; p++)
-	    if (ISWHITE(*p)) {
-		*p = '\0';
-		break;
-	    }
-	*fdp = StartChild(*fdp, path, cargv);
-	if (*fdp < 0)
-	    return false;
-	(*countp)++;
-	continue;
-#else
-        warn("bad_format unknown command %s", buff);
-	return false;
-#endif	/* defined(DO_RNEWSPROGS) */
+        if (additionalUnpackers) {
+            cargv[0] = UNPACK;
+            cargv[1] = NULL;
+            /* Ignore any possible leading pathnames, to avoid trouble. */
+            if ((p = strrchr(&buff[3], '/')) != NULL) {
+                p++;
+            } else {
+                p = &buff[3];
+            }
+            if (strchr(INN_PATH_RNEWSPROGS, '/') == NULL) {
+                snprintf(path, sizeof(path), "%s/%s/%s", innconf->pathbin,
+                         INN_PATH_RNEWSPROGS, p);
+                len = strlen(innconf->pathbin) + 1
+                    + sizeof(INN_PATH_RNEWSPROGS);
+            } else {
+                snprintf(path, sizeof(path), "%s/%s", INN_PATH_RNEWSPROGS, p);
+                len = sizeof(INN_PATH_RNEWSPROGS);
+            }
+            for (p = &path[len]; *p; p++)
+                if (ISWHITE(*p)) {
+                    *p = '\0';
+                    break;
+                }
+            *fdp = StartChild(*fdp, path, cargv);
+            if (*fdp < 0) {
+                return false;
+            }
+            (*countp)++;
+            continue;
+        } else {
+            warn("bad_format unknown command %s", buff);
+            return false;
+        }
     }
     return true;
 }
@@ -879,11 +881,20 @@ int main(int ac, char *av[])
     /* Parse JCL. */
     fd = STDIN_FILENO;
     mode = '\0';
-    while ((i = getopt(ac, av, "h:P:NUvr:S:")) != EOF)
+    while ((i = getopt(ac, av, "abdh:NP:r:S:Uv")) != EOF)
 	switch (i) {
 	default:
 	    die("usage error");
 	    /* NOTRTEACHED */
+        case 'a':
+            additionalUnpackers = false;
+            break;
+        case 'b':
+            backupBad = true;
+            break;
+        case 'd':
+            logDuplicates = true;
+            break;
 	case 'h':
 	    UUCPHost = *optarg ? optarg : NULL;
 	    break;
