@@ -1,4 +1,4 @@
-/* $Id: hisinterface.h 5745 2002-09-08 19:52:12Z rra $
+/* $Id: hisinterface.h 8571 2009-08-17 19:10:07Z iulius $
 **
 ** Interface to history API modules
 */
@@ -31,7 +31,7 @@ typedef struct hismethod {
     bool (*walk)(void *, const char *, void *,
 		 bool (*)(void *, time_t, time_t, time_t,
 			  const struct token *));
-    bool (*remember)(void *, const char *, time_t);
+    bool (*remember)(void *, const char *, time_t, time_t);
     bool (*ctl)(void *, int, void *);
 } HIS_METHOD;
 
@@ -43,5 +43,5 @@ enum { S_HIScacheadd, S_HIScachelookup, S_HISsetup, S_HISsync,
        S_HISwrite, S_HISremember, S_HIS_MAX };
 
 /* fine grained history logging */
-void his_logger(char *s, int code);
+void his_logger(const char *s, int code);
 #endif
