@@ -1,4 +1,4 @@
-/*  $Id: art.c 10149 2017-06-05 12:24:58Z iulius $
+/*  $Id: art.c 10513 2021-01-15 22:34:56Z iulius $
 **
 **  Article-processing.
 */
@@ -77,10 +77,6 @@ static char	ARTjnk[] = "junk";
 static char             hostcclass[256];
 #define ARThostchar(c)  ((hostcclass[(unsigned char)(c)]) != 0)
 
-#if defined(DO_PERL) || defined(DO_PYTHON)
-const char	*filterPath;
-#endif /* DO_PERL || DO_PYTHON */
-
 /* Prototypes. */
 static void ARTerror(CHANNEL *cp, const char *format, ...)
     __attribute__((__format__(printf, 2, 3)));
@@ -1942,6 +1938,7 @@ ARTpost(CHANNEL *cp)
 {
   char		*p, **groups, ControlWord[SMBUF], **hops, *controlgroup;
   int		i, j, *isp, hopcount, oerrno, canpost;
+  float         f;
   size_t        n;
   NEWSGROUP	*ngp, **ngptr;
   NEWSGROUP     *ngpjunk;
@@ -2072,10 +2069,6 @@ ARTpost(CHANNEL *cp)
     }
   }
 
-#if defined(DO_PERL) || defined(DO_PYTHON)
-  filterPath = HDR(HDR__PATH);
-#endif /* DO_PERL || DO_PYHTON */
-
 #if defined(DO_PYTHON)
   TMRstart(TMR_PYTHON);
   filterrc = PYartfilter(data, article->data + data->Body,
@@ -2539,7 +2532,7 @@ ARTpost(CHANNEL *cp)
     if (innconf->enableoverview && !innconf->useoverchan) {
       if ((result = OVadd(token, data->Overview.data, data->Overview.left,
 	data->Arrived, data->Expires)) == OVADDFAILED) {
-	if (OVctl(OVSPACE, (void *)&i) && i == OV_NOSPACE)
+	if (OVctl(OVSPACE, (void *)&f) && (int)(f+0.01f) == OV_NOSPACE)
 	  IOError("creating overview", ENOSPC);
 	else
 	  IOError("creating overview", 0);
