@@ -1,4 +1,4 @@
-/*  $Id: cc.c 9841 2015-05-02 16:27:37Z iulius $
+/*  $Id: cc.c 10523 2021-01-17 21:52:00Z iulius $
 **
 **  Routines for the control channel.
 **
@@ -19,6 +19,7 @@
 # include "portable/socket-unix.h"
 #endif
 
+#include "inn/fdflag.h"
 #include "inn/innconf.h"
 #include "inn/qio.h"
 #include "innd.h"
@@ -173,6 +174,54 @@ CCcurrmode(void)
 }
 
 
+/*
+**  Notify systemd of the current operating modes.
+*/
+static void
+CCsdnotify(void)
+{
+#ifdef HAVE_SD_NOTIFY
+    int status;
+
+    buffer_sprintf(&CCreply, "STATUS=Server ");
+
+    /* Server's mode. */
+    switch (Mode) {
+    default:
+        buffer_append_sprintf(&CCreply, "Unknown %d", Mode);
+        break;
+    case OMrunning:
+        buffer_append_sprintf(&CCreply, "running");
+        break;
+    case OMpaused:
+        buffer_append_sprintf(&CCreply, "paused %s", ModeReason);
+        break;
+    case OMthrottled:
+        buffer_append_sprintf(&CCreply, "throttled %s", ModeReason);
+        break;
+    }
+    if (RejectReason)
+        buffer_append_sprintf(&CCreply, ". Rejecting %s", RejectReason);
+
+    /* Newsreaders. */
+    buffer_append_sprintf(&CCreply, ". Readers ");
+    if (innconf->readerswhenstopped)
+        buffer_append_sprintf(&CCreply, "independent ");
+    else
+        buffer_append_sprintf(&CCreply, "follow ");
+    if (NNRPReason == NULL)
+        buffer_append_sprintf(&CCreply, "enabled.");
+    else
+        buffer_append_sprintf(&CCreply, "disabled %s.", NNRPReason);
+
+    buffer_append(&CCreply, "", 1);
+    status = sd_notify(false, CCreply.data);
+    if (status < 0)
+        warn("cannot notify systemd of new status: %s", strerror(-status));
+#endif
+}
+
+
 /*
 **  Add <> around Message-ID if needed.
 */
@@ -292,6 +341,7 @@ CCallow(char *av[])
 	return "1 Wrong reason";
     free(RejectReason);
     RejectReason = NULL;
+    CCsdnotify();
     return NULL;
 }
 
@@ -702,6 +752,7 @@ CCgo(char *av[])
 	ErrorCount = IO_ERROR_COUNT;
     InndHisOpen();
     syslog(L_NOTICE, "%s running", LogName);
+    CCsdnotify();
     if (ICDneedsetup)
 	ICDsetup(true);
     SCHANwakeup(&Mode);
@@ -1116,6 +1167,7 @@ CCparam(char *av[])
     case 'n':
 	if (!CCparsebool('n', (bool *)&innconf->readerswhenstopped, *p))
 	    return BADVAL;
+        CCsdnotify();
 	break;
     case 'o':
 	MaxOutgoing = atoi(p);
@@ -1198,6 +1250,7 @@ CCblock(OPERATINGMODE NewMode, char *reason)
     }
     syslog(L_NOTICE, "%s %s %s",
 	LogName, NewMode == OMpaused ? "paused" : "throttled", reason);
+    CCsdnotify();
     return NULL;
 }
 
@@ -1255,6 +1308,7 @@ CCreaders(char *av[])
 	NNRPReason = xstrdup(p);
 	break;
     }
+    CCsdnotify();
     return NULL;
 }
 
@@ -1268,6 +1322,9 @@ CCxexec(char *av[])
     char	*innd;
     char	*p;
     int		i;
+    const char  *s;
+    int         count;
+    int         status;
 
     if (CCargv == NULL)
 	return "1 no argv!";
@@ -1288,9 +1345,41 @@ CCxexec(char *av[])
 #endif
     JustCleanup();
     syslog(L_NOTICE, "%s execv %s", LogName, CCargv[0]);
+    status = sd_notify(false, "RELOADING=1");
+    if (status < 0)
+        warn("cannot notify systemd of reloading: %s", strerror(-status));
 
-    /* Close all fds to protect possible fd leaking accross successive innds. */
-    for (i=3; i<30; i++)
+    /* Restore the systemd variables which were backed up in RCsetup()
+       if socket activation was set. */
+    s = getenv("INN_BACKUP_LISTEN_FDS");
+    if (s != NULL) {
+        if (setenv("LISTEN_FDS", s, true) != 0)
+            die("setenv failed for LISTEN_FDS");
+        if (unsetenv("INN_BACKUP_LISTEN_FDS") != 0)
+            die("unsetenv failed for INN_BACKUP_LISTEN_FDS");
+    }
+    s = getenv("INN_BACKUP_LISTEN_PID");
+    if (s != NULL) {
+        if (setenv("LISTEN_PID", s, true) != 0)
+            die("setenv failed for LISTEN_PID");
+        if (unsetenv("INN_BACKUP_LISTEN_PID") != 0)
+            die("unsetenv failed for INN_BACKUP_LISTEN_PID");
+    }
+
+    /* Clear the close-on-exec flag on the socket activation file descriptors.
+       This is needed because we need to pass them to the new innd process
+       and sd_listen_fds(), which was called in RCsetup(), set it on all
+       passed file descriptors. */
+    s = getenv("INN_SD_LISTEN_FDS_COUNT");
+    if (s == NULL)
+        count = 0;
+    else
+        count = atoi(s);
+    for (i = SD_LISTEN_FDS_START; i < SD_LISTEN_FDS_START + count; i++)
+        fdflag_close_exec(i, false);
+
+    /* Close all fds to protect possible fd leaking across successive innds. */
+    for (i = SD_LISTEN_FDS_START + count; i < 30; i++)
         close(i);
 
     execv(CCargv[0], CCargv);
@@ -1313,6 +1402,7 @@ CCreject(char *av[])
     if (!is_valid_utf8(av[0]))
         return "1 Invalid UTF-8 reason";
     RejectReason = xstrdup(av[0]);
+    CCsdnotify();
     return NULL;
 }
 
@@ -1355,8 +1445,8 @@ CCreload(char *av[])
 #endif
 #ifdef DO_PYTHON
 	syslog(L_NOTICE, "reloading pyfilter");
-        PYreadfilter();
-	syslog(L_NOTICE, "reloaded pyfilter OK");
+        if (PYreadfilter())
+            syslog(L_NOTICE, "reloaded pyfilter OK");
 #endif
 	p = "all";
     }
@@ -2033,6 +2123,8 @@ CCsetup(void)
 #if     defined(SIGUSR1)
     xsignal(SIGUSR1, CCresetup);
 #endif  /* defined(SIGUSR1) */
+
+    CCsdnotify();
 }
 
 
