@@ -1,4 +1,4 @@
-/*  $Id: chan.c 10305 2018-12-02 14:21:56Z iulius $
+/*  $Id: chan.c 10523 2021-01-17 21:52:00Z iulius $
 **
 **  I/O channel (and buffer) processing.
 **
@@ -77,6 +77,29 @@ static struct channels channels;
 static CHANNEL CHANnull;
 
 
+/*
+**  Returns true if socket activation is used and the channel given as
+**  as argument is used for socket activation.  Returns false otherwise.
+*/
+bool
+CHANsystemdsa(CHANNEL *cp)
+{
+    const char *s;
+    int count;
+
+    s = getenv("INN_SD_LISTEN_FDS_COUNT");
+    if (s == NULL)
+        return false;
+
+    count = atoi(s);
+
+    if (cp->fd >= SD_LISTEN_FDS_START && cp->fd < SD_LISTEN_FDS_START + count)
+        return true;
+
+    return false;
+}
+
+
 /*
 **  Tear down our world.  Free all of the allocated channels and clear all
 **  global state data.  This function can also be used to initialize the
@@ -98,6 +121,8 @@ CHANshutdown(void)
     if (channels.table != NULL) {
         cp = channels.table;
         for (i = channels.table_size; --i >= 0; cp++) {
+            if (CHANsystemdsa(cp))
+                continue;
             if (cp->Type != CTfree)
                 CHANclose(cp, CHANname(cp));
             if (cp->In.data)
@@ -1195,7 +1220,13 @@ CHANreadloop(void)
 
         STATUSmainloophook();
         if (GotTerminate) {
-            warn("%s exiting due to signal", LogName);
+#ifdef DO_PERL
+            PLmode(Mode, OMshutdown, (char *) "exiting due to signal");
+#endif
+#ifdef DO_PYTHON
+            PYmode(Mode, OMshutdown, (char *) "exiting due to signal");
+#endif
+            notice("%s exiting due to signal", LogName);
             CleanupAndExit(0, NULL);
         }
 
