@@ -1,4 +1,4 @@
-/*  $Id: innd.h 10282 2018-05-14 12:42:14Z iulius $
+/*  $Id: innd.h 10523 2021-01-17 21:52:00Z iulius $
 **
 **  Many of the data types used here have abbreviations, such as CT for a
 **  channel type.  Here are a list of the conventions and meanings:
@@ -29,6 +29,7 @@
 
 #include "config.h"
 #include "portable/macros.h"
+#include "portable/sd-daemon.h"
 #include "portable/socket.h"
 #include <ctype.h>
 #include <errno.h>
@@ -722,11 +723,12 @@ extern void             ARTlogreject(CHANNEL *cp, const char *text);
 extern void		ARTreject(Reject_type, CHANNEL *);
 
 extern bool		CHANsleeping(CHANNEL *cp);
-extern CHANNEL      *	CHANcreate(int fd, enum channel_type Type,
-				   enum channel_state State,
-				   innd_callback_func Reader,
-				   innd_callback_func WriteDone);
-extern CHANNEL      *	CHANiter(int *cp, enum channel_type Type);
+extern bool             CHANsystemdsa(CHANNEL *cp);
+extern CHANNEL      *	CHANcreate(int fd, enum channel_type type,
+				   enum channel_state state,
+				   innd_callback_func reader,
+				   innd_callback_func write_done);
+extern CHANNEL      *	CHANiter(int *ip, enum channel_type type);
 extern CHANNEL      *	CHANfromdescriptor(int fd);
 extern char	    *   CHANname(CHANNEL *cp);
 extern int		CHANreadtext(CHANNEL *cp);
