@@ -1,4 +1,4 @@
-/*  $Id: ng.c 8426 2009-04-24 19:28:13Z iulius $
+/*  $Id: ng.c 9911 2015-07-04 21:32:56Z iulius $
 **
 **  Routine for the in-core data structures for the active and newsfeeds
 **  files.
@@ -323,8 +323,8 @@ NGsplit(char *p, int size, LISTBUFFER *list)
 /*
 **  Renumber a group.
 */
-static char		NORENUMBER[] = "%s cant renumber %s %s too wide";
-static char		RENUMBER[] = "%s renumber %s %s from %ld to %ld";
+#define NORENUMBER "%s cant renumber %s %s too wide"
+#define RENUMBER "%s renumber %s %s from %ld to %ld"
 
 bool
 NGrenumber(NEWSGROUP *ngp)
