@@ -1,11 +1,11 @@
-/*  $Id: proc.c 6124 2003-01-14 06:03:29Z rra $
+/*  $Id: proc.c 9904 2015-06-20 17:23:51Z iulius $
 **
 **  Process control routines.
 */
 
 #include "config.h"
 #include "clibrary.h"
-#include "portable/wait.h"
+#include <sys/wait.h>
 
 #include "innd.h"
 
@@ -36,29 +36,33 @@ PROCreap(void)
 	    break;
 	}
 	for (pp = PROCtable, i = PROCtablesize; --i >= 0; pp++)
-	    if (pp->Pid == pid) {
+            if (pp->State == PSrunning && pp->Pid == pid) {
 		PROCneedscan = true;
 		pp->Status = WEXITSTATUS(status);
 		pp->State = PSdead;
-		pp->Collected = Now.time;
+		pp->Collected = Now.tv_sec;
 		break;
 	    }
     }
 }
 
 
+#ifdef HAVE_SIGACTION
+#define NO_SIGACTION_UNUSED UNUSED
+#else
+#define NO_SIGACTION_UNUSED
+#endif
+
 /*
 **  Signal handler that collects the processes, then resets the signal.
 */
-static RETSIGTYPE
-PROCcatchsignal(int s)
+static void
+PROCcatchsignal(int s NO_SIGACTION_UNUSED)
 {
     PROCreap();
 
 #ifndef HAVE_SIGACTION
     xsignal(s, PROCcatchsignal);
-#else
-    s = s;			/* ARGSUSED */
 #endif
 }
 
@@ -153,7 +157,7 @@ PROCwatch(pid_t pid, int site)
 
     pp->State = PSrunning;
     pp->Pid = pid;
-    pp->Started = Now.time;
+    pp->Started = Now.tv_sec;
     pp->Site = site;
     return pp - PROCtable;
 }
