@@ -1,4 +1,4 @@
-/*  $Id: python.c 10305 2018-12-02 14:21:56Z iulius $
+/*  $Id: python.c 10442 2020-12-09 21:04:31Z iulius $
 **
 **  Embed Python in the style of innd's Perl stuff.
 **
@@ -60,7 +60,6 @@
 #include "innd.h"
 
 bool		PythonFilterActive;
-char		*filterPath;	/* This gets set in art.c. */
 PyObject	*PYFilterObject = NULL;
 PyObject	*PYFilterModule = NULL;
 
@@ -685,8 +684,8 @@ PYreadfilter(void)
     PyObject	*result;
 
     if (!Py_IsInitialized()) {
-	syslog(L_ERROR, "python is not initialized");
-	return 0;
+        syslog(L_NOTICE, "python is not initialized");
+        return 0;
     }
 
     /* If there is a filter running, let it clean up first. */
@@ -741,6 +740,16 @@ PYsetup(void)
 {
     const ARTHEADER *hp;
     size_t hdrcount;
+    char *path;
+
+    path = concatpath(innconf->pathfilter, INN_PATH_PYTHON_STARTUP);
+    if (access(path, R_OK) < 0) {
+        syslog(L_NOTICE, "pyfilter %s not installed", path);
+        PYfilter(false);
+        free(path);
+        return;
+    }
+    free(path);
 
     /* Add path for innd module.  The environment variable PYTHONPATH
      * does it; one can also append innconf->pathfilter to sys.path once
