@@ -1,4 +1,4 @@
-/*  $Id: innlistener.c 10009 2016-05-05 12:39:19Z iulius $
+/*  $Id: innlistener.c 10152 2017-06-05 12:27:29Z iulius $
 **
 **  The implementation of the innfeed InnListener class.
 **
@@ -669,7 +669,8 @@ static void giveArticleToPeer (InnListener lis,
 
 static void writeCheckPoint (int offsetAdjust)
 {
-  char offsetString[16], *writePointer ;
+  char offsetString[21]; /* size of long long may be 20 */
+  char *writePointer;
   off_t offset ;
   int writeBytes, writeReturn, mainFd ;
 	      
