@@ -1,4 +1,4 @@
-/*  $Id: main.c 10009 2016-05-05 12:39:19Z iulius $
+/*  $Id: main.c 10153 2017-06-05 12:28:01Z iulius $
 **
 **  Main routines for the innfeed program.
 **
@@ -93,7 +93,7 @@ static void sigquit (int sig) ;
 static void sighup (int sig) ;
 static void sigterm (int sig) ;
 static void sigusr (int sig) ;
-static void usage (int) ;
+static void usage (int) __attribute__ ((__noreturn__)) ;
 static void gprintinfo (void) ;
 static void openLogFile (void) ;
 static void writePidFile (void) ;
