@@ -1,4 +1,4 @@
-/*  $Id: misc.c 10040 2016-07-31 20:01:43Z iulius $
+/*  $Id: misc.c 10305 2018-12-02 14:21:56Z iulius $
 **
 **  Helper routines for the innfeed program.
 **
@@ -381,7 +381,7 @@ void deadBeef (void *base, size_t byteCount)
 bool lockFile (const char *fileName)
 {
   char buff [20] ;
-  char tmpName [PATH_MAX], realName [PATH_MAX] ;
+  char tmpName [PATH_MAX+sizeof(long)+10], realName [PATH_MAX] ;
   char *p ;
   int fd, i ;
   pid_t pid = getpid () ;
