@@ -1,9 +1,9 @@
-/* $Id: getnameinfo.c 10105 2016-11-04 22:42:26Z iulius $
+/* $Id: getnameinfo.c 10444 2020-12-09 21:06:15Z iulius $
  *
  * Replacement for a missing getnameinfo.
  *
  * This is an implementation of getnameinfo for systems that don't have one so
- * that networking code can use a consistant interface without #ifdef.  It is
+ * that networking code can use a consistent interface without #ifdef.  It is
  * a fairly minimal implementation, with the following limitations:
  *
  *   - IPv4 support only.  IPv6 is not supported.
@@ -18,14 +18,16 @@
  * which can be found at <https://www.eyrie.org/~eagle/software/rra-c-util/>.
  *
  * Written by Russ Allbery <eagle@eyrie.org>
+ * Copyright 2005, 2020 Russ Allbery <eagle@eyrie.org>
+ * Copyright 2008, 2011, 2013-2014
+ *     The Board of Trustees of the Leland Stanford Junior University
  *
- * The authors hereby relinquish any claim to any copyright that they may have
- * in this work, whether granted under contract or by operation of law or
- * international treaty, and hereby commit to the public, at large, that they
- * shall not, at any time in the future, seek to enforce any copyright in this
- * work against any person or entity, or prevent any person or entity from
- * copying, publishing, distributing or creating derivative works of this
- * work.
+ * Copying and distribution of this file, with or without modification, are
+ * permitted in any medium without royalty provided the copyright notice and
+ * this notice are preserved.  This file is offered as-is, without any
+ * warranty.
+ *
+ * SPDX-License-Identifier: FSFAP
  */
 
 #include "config.h"
@@ -33,6 +35,7 @@
 #include "portable/socket.h"
 #include "clibrary.h"
 
+#include <ctype.h>
 #include <errno.h>
 
 /*
@@ -41,33 +44,52 @@
  * constants, but that should be okay (except possibly for gai_strerror).
  */
 #if TESTING
-# undef getnameinfo
-# define getnameinfo test_getnameinfo
+#    undef getnameinfo
+#    define getnameinfo test_getnameinfo
 int test_getnameinfo(const struct sockaddr *, socklen_t, char *, socklen_t,
                      char *, socklen_t, int);
 
 /* Linux doesn't provide EAI_OVERFLOW, so make up our own for testing. */
-# ifndef EAI_OVERFLOW
-#  define EAI_OVERFLOW 10
-# endif
+#    ifndef EAI_OVERFLOW
+#        define EAI_OVERFLOW 10
+#    endif
 #endif
 
 /* Used for unused parameters to silence gcc warnings. */
-#define UNUSED  __attribute__((__unused__))
+#define UNUSED __attribute__((__unused__))
 
 
 /*
  * Check to see if a name is fully qualified by seeing if it contains a
  * period.  If it does, try to copy it into the provided node buffer and set
  * status accordingly, returning true.  If not, return false.
+ *
+ * musl libc returns the text form of the IP address rather than NULL when the
+ * IP address doesn't resolve.  Reject such names here so that NI_NAMEREQD is
+ * emulated correctly.
  */
 static bool
 try_name(const char *name, char *node, socklen_t nodelen, int *status)
 {
     size_t namelen;
+    const char *p;
+    bool found_nondigit = false;
 
+    /* Reject unqualified names. */
     if (strchr(name, '.') == NULL)
         return false;
+
+    /*
+     * Reject names consisting entirely of digits and period, since these are
+     * converted IP addresses rather than resolved names.
+     */
+    for (p = name; *p != '\0'; p++)
+        if (!isdigit((unsigned char) *p) && *p != '.')
+            found_nondigit = true;
+    if (!found_nondigit)
+        return false;
+
+    /* Copy the name if it's not too long and return success. */
     namelen = strlen(name);
     if (namelen + 1 > (size_t) nodelen)
         *status = EAI_OVERFLOW;
