@@ -1,8 +1,8 @@
-/*  $Id: hashtab.c 7585 2006-11-21 09:37:51Z eagle $
+/*  $Id: hashtab.c 10153 2017-06-05 12:28:01Z iulius $
 **
 **  Generic hash table implementation.
 **
-**  Written by Russ Allbery <rra@stanford.edu>
+**  Written by Russ Allbery <eagle@eyrie.org>
 **  This work is hereby placed in the public domain by its author.
 **
 **  This is a generic hash table implementation with linear probing.  It
@@ -57,6 +57,9 @@ hash_size(size_t target)
     int n;
     size_t size;
 
+    if (target == 0) {
+        return 4;
+    }
     size = target - 1;
     for (n = 0; size > 0; n++)
         size >>= 1;
@@ -428,18 +431,28 @@ hash_lookup2(const char *key, size_t length, unsigned long partial)
     c += length;
     switch (len) {
     case 11: c += S3(key[10]);
+             /* fallthrough */
     case 10: c += S2(key[9]);
+             /* fallthrough */
     case  9: c += S1(key[8]);
-        /* The first byte of c is reserved for the length. */
+             /* The first byte of c is reserved for the length. */
+             /* fallthrough */
     case  8: b += S3(key[7]);
+             /* fallthrough */
     case  7: b += S2(key[6]);
+             /* fallthrough */
     case  6: b += S1(key[5]);
+             /* fallthrough */
     case  5: b += S0(key[4]);
+             /* fallthrough */
     case  4: a += S3(key[3]);
+             /* fallthrough */
     case  3: a += S2(key[2]);
+             /* fallthrough */
     case  2: a += S1(key[1]);
+             /* fallthrough */
     case  1: a += S0(key[0]);
-        /* case 0: nothing left to add. */
+             /* case 0: nothing left to add. */
     }
     MIX(a, b, c);
     return c;
