@@ -1,4 +1,4 @@
-/* $Id: vector.c 10246 2018-02-16 21:12:42Z iulius $
+/* $Id: vector.c 10396 2020-11-12 20:19:41Z iulius $
  *
  * Vector handling (counted lists of char *'s).
  *
@@ -25,7 +25,7 @@
  * which can be found at <https://www.eyrie.org/~eagle/software/rra-c-util/>.
  *
  * Written by Russ Allbery <eagle@eyrie.org>
- * Copyright 2001-2006, 2016 Russ Allbery <eagle@eyrie.org>
+ * Copyright 2001-2006, 2016, 2020 Russ Allbery <eagle@eyrie.org>
  * Copyright 2005-2006, 2008-2011, 2013-2014
  *     The Board of Trustees of the Leland Stanford Junior University
  *
@@ -102,8 +102,8 @@ cvector_resize(struct cvector *vector, size_t size)
         vector->count = size;
     if (size == 0)
         size = 1;
-    vector->strings
-        = xreallocarray(vector->strings, size, sizeof(const char *));
+    vector->strings =
+        xreallocarray(vector->strings, size, sizeof(const char *));
     vector->allocated = size;
 }
 
@@ -328,7 +328,7 @@ split_multi_count(const char *string, const char *seps)
         return 0;
 
     /*
-     * Walk the string looking for the first separator not preceeded by
+     * Walk the string looking for the first separator not preceded by
      * another separator (and ignore a separator at the start of the string).
      */
     for (count = 1, p = string + 1; *p != '\0'; p++)
@@ -351,8 +351,7 @@ split_multi_count(const char *string, const char *seps)
  * are considered a single separator.  Reuse the provided vector if non-NULL.
  */
 struct vector *
-vector_split_multi(const char *string, const char *seps,
-                   struct vector *vector)
+vector_split_multi(const char *string, const char *seps, struct vector *vector)
 {
     const char *p, *start;
     size_t i, count;
@@ -550,7 +549,7 @@ vector_exec(const char *path, struct vector *vector)
     if (vector->allocated == vector->count)
         vector_resize(vector, vector->count + 1);
     vector->strings[vector->count] = NULL;
-    return execv(path, (char * const *) vector->strings);
+    return execv(path, (char *const *) vector->strings);
 }
 
 int
@@ -560,5 +559,5 @@ cvector_exec(const char *path, struct cvector *vector)
     if (vector->allocated == vector->count)
         cvector_resize(vector, vector->count + 1);
     vector->strings[vector->count] = NULL;
-    return execv(path, (char * const *) vector->strings);
+    return execv(path, (char *const *) vector->strings);
 }
