@@ -1,4 +1,4 @@
-/*  $Id: line.c 9563 2013-11-10 13:13:34Z iulius $
+/*  $Id: line.c 9979 2015-12-11 20:40:29Z iulius $
 **
 **  Line by line reading support from sockets/pipes.
 **
@@ -27,6 +27,7 @@
 extern SSL *tls_conn;
 #endif
 
+
 /*
 **  Free a previously allocated line structure.
 */
@@ -86,6 +87,39 @@ line_doread(void *p, size_t len, int timeout UNUSED)
     ssize_t n;
 
     do {
+#if defined(HAVE_ZLIB)
+        /* Process data that may already be available in the zlib buffer. */
+        if (compression_layer_on &&
+            (zstream_in->avail_in > 0 || zstream_inflate_needed)) {
+            int r;
+
+            zstream_in->next_out = p;
+            zstream_in->avail_out = len;
+
+            r = inflate(zstream_in, Z_SYNC_FLUSH);
+
+            if (!(r == Z_OK || r == Z_BUF_ERROR || r == Z_STREAM_END)) {
+                sysnotice("inflate() failed: %d; %s", r,
+                          zstream_in->msg != NULL ? zstream_in->msg :
+                          "no detail");
+                n = -1;
+                break;
+            }
+
+            /* Check whether inflate() has finished to process its input.
+             * If not, we need to call it again, even though avail_in is 0. */
+            zstream_inflate_needed = (r != Z_STREAM_END);
+
+            if (zstream_in->avail_out < len) {
+                /* Some data has been uncompressed.  Treat it now. */
+                n = len - zstream_in->avail_out;
+                break;
+            }
+            /* If we reach here, then it means that inflate() needs more
+             * input, so we go on reading data on the wire. */
+        }
+#endif /* HAVE_ZLIB */
+
 #ifdef HAVE_OPENSSL
 	if (tls_conn) {
 	    int err;
@@ -119,25 +153,79 @@ line_doread(void *p, size_t len, int timeout UNUSED)
 	if (n <= 0)
             break; /* EOF or error. */
 
-#ifdef HAVE_SASL
-	if (sasl_conn && sasl_ssf) {
-	    /* Security layer in place, decode the data. */
-	    const char *out;
-	    unsigned outlen;
-	    int r;
+#if defined(HAVE_SASL)
+        if (sasl_conn != NULL && sasl_ssf > 0) {
+            /* Security layer in place, decode the data.
+             * The incoming data is always encoded in chunks of length
+             * inferior or equal to NNTP_MAXLEN_COMMAND (the maxbufsize value
+             * of SASL_SEC_PROPS passed as part of the SASL exchange).
+             * So there's enough data to read in the p buffer. */
+            const char *out;
+            unsigned outlen;
+            int r;
 
-	    if ((r = sasl_decode(sasl_conn, p, n, &out, &outlen)) == SASL_OK) {
-		if (outlen)
-                    memcpy(p, out, outlen);
-		n = outlen;
-	    } else {
-		sysnotice("sasl_decode() failed: %s; %s",
-			  sasl_errstring(r, NULL, NULL),
-			  sasl_errdetail(sasl_conn));
-		n = -1;
-	    }
-	}
+            if ((r = sasl_decode(sasl_conn, p, n, &out, &outlen)) == SASL_OK) {
+                if (outlen > len) {
+                    sysnotice("sasl_decode() returned too much output");
+                    n = -1;
+                } else {
+                    if (outlen > 0) {
+                        memcpy(p, out, outlen);
+                    }
+                    n = outlen;
+                }
+            } else {
+                const char *ed = sasl_errdetail(sasl_conn);
+
+                sysnotice("sasl_decode() failed: %s; %s",
+                          sasl_errstring(r, NULL, NULL),
+                          ed != NULL ? ed : "no detail");
+                n = -1;
+            }
+        }
 #endif /* HAVE_SASL */
+
+#if defined(HAVE_ZLIB)
+        if (compression_layer_on && n > 0) {
+            size_t zconsumed;
+
+            if (zstream_in->avail_in > 0 && zstream_in->next_in != Z_NULL) {
+                zconsumed = zstream_in->next_in - zbuf_in;
+            } else {
+                zconsumed = 0;
+                zbuf_in_allocated = 0;
+            }
+
+            /* Transfer the data we have just read to zstream_in,
+             * and loop to actually process it. */
+            if ((ssize_t) (zbuf_in_size - zbuf_in_allocated) < n) {
+                size_t newsize = zbuf_in_size * 2 + n;
+
+                /* Don't grow the buffer bigger than the maximum
+                 * article size we'll accept. */
+                if (PERMaccessconf->localmaxartsize > NNTP_MAXLEN_COMMAND) {
+                    if (newsize > PERMaccessconf->localmaxartsize) {
+                        newsize = PERMaccessconf->localmaxartsize;
+                    }
+                }
+                if (newsize == zbuf_in_size) {
+                    warn("%s overflowed our zstream_in buffer (%lu)",
+                         Client.host, (unsigned long) newsize);
+                    n = -1;
+                    break;
+                }
+                zbuf_in = xrealloc(zbuf_in, newsize);
+                zbuf_in_size = newsize;
+            }
+            memcpy(zbuf_in + zbuf_in_allocated, p, n);
+            zstream_in->next_in = zbuf_in + zconsumed;
+            zstream_in->avail_in += n;
+            zbuf_in_allocated += n;
+            zstream_inflate_needed = true;
+            /* Loop to actually inflate the compressed data we received. */
+            n = 0;
+        }
+#endif /* HAVE_ZLIB */
     } while (n == 0); /* Split SASL blob, need to read more data. */
 
     return n;
