@@ -1,4 +1,4 @@
-/*  $Id: nnrpd.h 10121 2016-11-23 21:32:53Z iulius $
+/*  $Id: nnrpd.h 10306 2018-12-02 14:26:13Z iulius $
 **
 **  NetNews Reading Protocol server.
 */
@@ -26,17 +26,11 @@
 #include "inn/vector.h"
 #include "inn/timer.h"
 
-#ifndef HAVE_SASL_SASL_H
-# undef HAVE_SASL
-#endif
 #ifdef HAVE_SASL
 #include <sasl/sasl.h>
 #include <sasl/saslutil.h>
 #endif
 
-#if !defined(HAVE_ZLIB_H)
-# undef HAVE_ZLIB
-#endif
 #if defined(HAVE_ZLIB)
 # include <zlib.h>
 #endif
@@ -230,7 +224,6 @@ extern int		TrimSpaces(char *line);
 extern void		InitBackoffConstants(void);
 extern char		*PostRecFilename(char *ip, char *user);
 extern int		LockPostRec(char *path);
-extern int		LockPostRec(char *path);
 extern void		UnlockPostRec(char *path);
 extern int		RateLimit(long *sleeptime, char *path);
 extern void		ExitWithStats(int x, bool readconf)
@@ -309,6 +302,11 @@ void PY_access(char* path, struct vector *access_vec, char *Username);
 void PY_close_python(void);
 int PY_dynamic(char *Username, char *NewsGroup, int PostFlag, char **reply_message);
 void PY_dynamic_init (char* file);
+# if PY_MAJOR_VERSION >= 3
+extern PyMODINIT_FUNC   PyInit_nnrpd(void);
+# else
+extern void             PyInit_nnrpd(void);
+# endif
 #endif	/* DO_PYTHON */
 
 void line_free(struct line *);
