@@ -1,4 +1,4 @@
-/*  $Id: perl.c 9497 2013-06-25 17:40:59Z iulius $
+/*  $Id: perl.c 10305 2018-12-02 14:21:56Z iulius $
 **
 **  Embedded Perl support for INN.
 **
@@ -26,14 +26,15 @@
 #ifdef DO_PERL
 
 #include <EXTERN.h>
+#pragma GCC diagnostic ignored "-Wredundant-decls"
 #include <perl.h>
+#pragma GCC diagnostic warning "-Wredundant-decls"
 #include <XSUB.h>
 #include "ppport.h"
 
 #include "innperl.h"
 
 extern HEADER Table[], *EndOfTable;
-extern char PERMuser[];
 
 extern char **OtherHeaders;
 extern int OtherCount;
@@ -44,7 +45,7 @@ extern bool PerlLoaded;
 /* #define DEBUG_MODIFY only if you want to see verbose output. */
 #ifdef DEBUG_MODIFY
 static FILE *flog;
-void dumpTable(char *msg);
+void dumpTable(const char *msg);
 #endif /* DEBUG_MODIFY */
 
 char *
@@ -66,6 +67,7 @@ HandleHeaders(char *article)
     int OtherSize;
     char *argv[] = { NULL };
     bool failure;
+    SV *errsv;
 
     if(!PerlLoaded) {
         loadPerl();
@@ -194,10 +196,11 @@ HandleHeaders(char *article)
     buf[0] = '\0';
 
     /* Check $@. */
-    if (SvTRUE(ERRSV)) {
+    errsv = ERRSV;
+    if (SvTRUE(errsv)) {
         failure = true;
         syslog(L_ERROR, "Perl function filter_post died: %s",
-               SvPV(ERRSV, PL_na));
+               SvPV(errsv, PL_na));
         (void)POPs;
     } else {
         failure = false;
@@ -247,6 +250,7 @@ perlAccess(char *user, struct vector *access_vec)
     SV *sv;
     int rc, i;
     char *key, *val, *buffer;
+    SV *errsv;
 
     if (!PerlFilterActive)
         return;
@@ -277,8 +281,9 @@ perlAccess(char *user, struct vector *access_vec)
     SPAGAIN;
 
     if (rc == 0) { /* Error occured, same as checking $@. */
+        errsv = ERRSV;
         syslog(L_ERROR, "Perl function access died: %s",
-               SvPV(ERRSV, PL_na));
+               SvPV(errsv, PL_na));
         Reply("%d Internal error (1).  Goodbye!\r\n", NNTP_FAIL_TERMINATING);
         ExitWithStats(1, true);
     }
@@ -321,6 +326,7 @@ perlAuthInit(void)
 {
     dSP;
     int rc;
+    SV *errsv;
 
     if (!PerlFilterActive)
         return;
@@ -338,9 +344,10 @@ perlAuthInit(void)
 
     SPAGAIN;
 
-    if (SvTRUE(ERRSV)) {    /* Check $@. */
+    errsv = ERRSV;
+    if (SvTRUE(errsv)) {    /* Check $@. */
         syslog(L_ERROR, "Perl function authenticate died: %s",
-               SvPV(ERRSV, PL_na));
+               SvPV(errsv, PL_na));
         Reply("%d Internal error (1).  Goodbye!\r\n", NNTP_FAIL_TERMINATING);
         ExitWithStats(1, true);
     }
@@ -362,6 +369,7 @@ perlAuthenticate(char *user, char *passwd, int *code, char *errorstring, char *n
     HV *attribs;
     int rc;
     char *p;
+    SV *errsv;
 
     if (!PerlFilterActive)
         *code = NNTP_FAIL_AUTHINFO_BAD;
@@ -391,8 +399,9 @@ perlAuthenticate(char *user, char *passwd, int *code, char *errorstring, char *n
     SPAGAIN;
 
     if (rc == 0 ) { /* Error occurred, same as checking $@. */
+        errsv = ERRSV;
         syslog(L_ERROR, "Perl function authenticate died: %s",
-               SvPV(ERRSV, PL_na));
+               SvPV(errsv, PL_na));
         Reply("%d Internal error (1).  Goodbye!\r\n", NNTP_FAIL_TERMINATING);
         ExitWithStats(1, false);
     }
@@ -426,7 +435,7 @@ perlAuthenticate(char *user, char *passwd, int *code, char *errorstring, char *n
 
 #ifdef DEBUG_MODIFY
 void
-dumpTable (char *msg)
+dumpTable (const char *msg)
 {
     HEADER *hp;
     int i;
