@@ -1,4 +1,4 @@
-/*  $Id: python.c 10313 2018-12-17 08:46:18Z iulius $
+/*  $Id: python.c 10447 2020-12-09 21:19:29Z iulius $
 **
 **  python.c:  Embed Python in the style of nnrpd's Perl stuff
 **             (authentication, authorization and dynamic hooks
@@ -392,12 +392,16 @@ PY_access(char* file, struct vector *access_vec, char *User)
 /*
 **  Initialize dynamic access control code.
 */
-
 void
 PY_dynamic_init (char* file)
 {
-  dynamic_file = xstrdup(file);
-  PY_use_dynamic = true;
+    if (!access(file, R_OK)) {
+        syslog(L_NOTICE, "pyfilter %s not installed", file);
+        return;
+    }
+
+    dynamic_file = xstrdup(file);
+    PY_use_dynamic = true;
 }
 
 
