@@ -1,7 +1,7 @@
 ##########################################################################
 # INN module for innreport (3.*).
 #
-# $Id: innreport_inn.pm 10320 2018-12-29 13:46:28Z iulius $
+# $Id: innreport_inn.pm 10442 2020-12-09 21:04:31Z iulius $
 #
 # Sample file tested with INN 2.5, 2.4, 2.3, 2.2, 1.7.2 and 1.5.1.
 #
@@ -473,6 +473,8 @@ sub collect($$$$$$) {
     return 1 if $left =~ /^reloading pyfilter$/o;
     return 1 if $left =~ /^reloaded pyfilter OK$/o;
     return 1 if $left =~ /^python interpreter initialized OK$/o;
+    return 1 if $left =~ /^python is not initialized$/o;
+    return 1 if $left =~ /^pyfilter .+ not installed$/o;
     return 1 if $left =~ /^python method \w+ not found$/o; 
     return 1 if $left =~ /^python: First load, so I can do initialization stuff\.$/o;
     return 1 if $left =~ /^python: filter_before_reload executing\.\.\.$/o;
@@ -1877,22 +1879,12 @@ sub collect($$$$$$) {
       $rnews_host{$host}++;
       return 1;
     }
-    # rejected 437 ECP rejected
-    return 1 if $left =~ m/rejected (?:437|439) ECP rejected/o;
     # rejected 437 "Subject" header too long
     return 1 if $left =~ m/header too long/o;
-    # rejected 437 Too long line in header 1163 bytes
-    return 1 if $left =~ m/rejected (?:437|439) Too long line in header/o;
-    # rejected 437 Too many newsgroups (meow)
-    return 1 if $left =~ m/rejected (?:437|439) Too many newsgroups/o;
-    # rejected 437 Space before colon in "<a" header
-    return 1 if $left =~ m/rejected (?:437|439) Space before colon in/o;
-    # rejected 437 EMP (phl)
-    return 1 if $left =~ m/rejected (?:437|439) EMP/o;
-    # rejected 437 Scoring filter (8)
-    return 1 if $left =~ m/rejected (?:437|439) Scoring filter/o;
-    # bad_article missing Message-ID
-    return 1 if $left =~ m/bad_article missing Message-ID/o;
+    # rejected 437 Reason...
+    return 1 if $left =~ m/rejected (?:437|439)/o;
+    # bad_article missing (Message-ID|Path|...)
+    return 1 if $left =~ m/bad_article missing /o;
     # cant unspool saving to xxx
     return 1 if $left =~ m/cant unspool saving to/o;
   }
