@@ -1,4 +1,4 @@
-/*  $Id: buffindexed.c 10305 2018-12-02 14:21:56Z iulius $
+/*  $Id: buffindexed.c 10513 2021-01-15 22:34:56Z iulius $
 **
 **  Overview buffer and index method.
 */
@@ -552,15 +552,22 @@ static void ovflushhead(OVBUFF *ovbuff) {
  
   memset(&rpx, 0, sizeof(OVBUFFHEAD));
   ovbuff->updated = time(NULL);
+  /* Don't use sprintf() or strlcat() directly...
+   * The terminating '\0' causes grief. */
+#if __GNUC__ > 7
+# pragma GCC diagnostic ignored "-Wstringop-truncation"
+#endif
   strncpy(rpx.magic, OVBUFF_MAGIC, strlen(OVBUFF_MAGIC));
   strncpy(rpx.path, ovbuff->path, OVBUFFPASIZ);
-  /* Don't use sprintf() directly ... the terminating '\0' causes grief */
   strncpy(rpx.indexa, offt2hex(ovbuff->index, true), OVBUFFLASIZ);
   strncpy(rpx.lena, offt2hex(ovbuff->len, true), OVBUFFLASIZ);
   strncpy(rpx.totala, offt2hex(ovbuff->totalblk, true), OVBUFFLASIZ);
   strncpy(rpx.useda, offt2hex(ovbuff->usedblk, true), OVBUFFLASIZ);
   strncpy(rpx.freea, offt2hex(ovbuff->freeblk, true), OVBUFFLASIZ);
   strncpy(rpx.updateda, offt2hex(ovbuff->updated, true), OVBUFFLASIZ);
+#if __GNUC__ > 7
+# pragma GCC diagnostic warning "-Wstringop-truncation"
+#endif
   rpx.version = OVBUFF_VERSION;
   rpx.freeblk = ovbuff->freeblk;
   rpx.usedblk = ovbuff->usedblk;
@@ -2203,6 +2210,7 @@ buffindexed_expiregroup(const char *group, int *lo, struct history *h)
 
 bool buffindexed_ctl(OVCTLTYPE type, void *val) {
   int			total, used, *i, j;
+  float                 *f;
   OVBUFF		*ovbuff = ovbufftab;
   OVSORTTYPE		*sorttype;
   bool			*boolval;
@@ -2217,8 +2225,8 @@ bool buffindexed_ctl(OVCTLTYPE type, void *val) {
       used += ovbuff->usedblk;
       ovlock(ovbuff, INN_LOCK_UNLOCK);
     }
-    i = (int *)val;
-    *i = (used * 100) / total;
+    f = (float *)val;
+    *f = ((float)used / total) * 100;
     return true;
   case OVSORT:
     sorttype = (OVSORTTYPE *)val;
@@ -2467,9 +2475,9 @@ main(int argc, char **argv) {
     }
   }
   {
-    ARTNUM artnum;
-    char *data;
-    int len;
+    ARTNUM artnum = 0;
+    char *data = NULL;
+    int len = 0;
     TOKEN token;
     while (buffindexed_search((void *)search, &artnum, &data, &len, &token, NULL)) {
       if (len == 0)
