@@ -1,4 +1,4 @@
-/*  $Id: cnfs-private.h 8599 2009-08-29 08:34:46Z iulius $
+/*  $Id: cnfs-private.h 10397 2020-11-12 20:22:51Z iulius $
 **
 **  CNFS disk/file mode header file.
 */
@@ -7,7 +7,9 @@
 #define CNFS_PRIVATE_H 1
 
 #include <sys/types.h>
-#include <unistd.h>
+#if HAVE_UNISTD_H
+# include <unistd.h>
+#endif
 
 #define _PATH_CYCBUFFCONFIG	"cycbuff.conf"
 
