@@ -1,4 +1,4 @@
-/*  $Id: cnfs.c 10305 2018-12-02 14:21:56Z iulius $
+/*  $Id: cnfs.c 10342 2019-05-30 14:18:48Z iulius $
 **
 **  Storage manager module for Cyclic News File System method.
 */
@@ -234,13 +234,17 @@ static bool CNFSflushhead(CYCBUFF *cycbuff) {
   memset(&rpx, 0, sizeof(CYCBUFFEXTERN));
   if (cycbuff->magicver == 3 || cycbuff->magicver == 4) {
     cycbuff->updated = time(NULL);
+    /* Don't use sprintf() or strlcat() directly...
+     * The terminating '\0' causes grief. */
+#if __GNUC__ > 7
+# pragma GCC diagnostic ignored "-Wstringop-truncation"
+#endif
     if (cycbuff->magicver == 3)
 	strncpy(rpx.magic, CNFS_MAGICV3, strlen(CNFS_MAGICV3));
     else
 	strncpy(rpx.magic, CNFS_MAGICV4, strlen(CNFS_MAGICV4));
     strncpy(rpx.name, cycbuff->name, CNFSNASIZ);
     strncpy(rpx.path, cycbuff->path, CNFSPASIZ);
-    /* Don't use sprintf() directly ... the terminating '\0' causes grief */
     strncpy(rpx.lena, CNFSofft2hex(cycbuff->len, true), CNFSLASIZ);
     strncpy(rpx.freea, CNFSofft2hex(cycbuff->free, true), CNFSLASIZ);
     strncpy(rpx.cyclenuma, CNFSofft2hex(cycbuff->cyclenum, true), CNFSLASIZ);
@@ -253,6 +257,9 @@ static bool CNFSflushhead(CYCBUFF *cycbuff) {
 	strncpy(rpx.currentbuff, "FALSE", CNFSMASIZ);
     }
     strncpy(rpx.blksza, CNFSofft2hex(cycbuff->blksz, true), CNFSLASIZ);
+#if __GNUC__ > 7
+# pragma GCC diagnostic warning "-Wstringop-truncation"
+#endif
     memcpy(cycbuff->bitfield, &rpx, sizeof(CYCBUFFEXTERN));
     msync(cycbuff->bitfield, cycbuff->minartoffset, MS_ASYNC);
     cycbuff->needflush = false;
@@ -660,7 +667,7 @@ static bool CNFSinit_disks(CYCBUFF *cycbuff) {
 	strncpy(buf, rpx->cyclenuma, CNFSLASIZ);
         buf[CNFSLASIZ] = '\0';
 	cycbuff->cyclenum = CNFShex2offt(buf);
-	strncpy(cycbuff->metaname, rpx->metaname, CNFSLASIZ);
+	strncpy(cycbuff->metaname, rpx->metaname, CNFSNASIZ);
 	strncpy(buf, rpx->orderinmeta, CNFSLASIZ);
 	cycbuff->order = CNFShex2offt(buf);
 	if (strncmp(rpx->currentbuff, "TRUE", CNFSMASIZ) == 0) {
@@ -690,7 +697,7 @@ static bool CNFSinit_disks(CYCBUFF *cycbuff) {
 	cycbuff->needflush = true;
 	cycbuff->blksz = CNFS_DFL_BLOCKSIZE;
 	cycbuff->free = 0;
-	memset(cycbuff->metaname, '\0', CNFSLASIZ);
+	memset(cycbuff->metaname, '\0', CNFSNASIZ);
     }
     /*
     ** The minimum article offset will be the size of the bitfield itself,
@@ -734,7 +741,15 @@ static bool CNFS_setcurrent(METACYCBUFF *metacycbuff) {
       /* this cycbuff is moved from other metacycbuff , or is new */
       cycbuff->order = i + 1;
       cycbuff->currentbuff = false;
-      strncpy(cycbuff->metaname, metacycbuff->name, CNFSLASIZ);
+      /* Don't use sprintf() or strlcat() directly...
+       * The terminating '\0' causes grief. */
+#if __GNUC__ > 7
+# pragma GCC diagnostic ignored "-Wstringop-truncation"
+#endif
+      strncpy(cycbuff->metaname, metacycbuff->name, CNFSNASIZ);
+#if __GNUC__ > 7
+# pragma GCC diagnostic warning "-Wstringop-truncation"
+#endif
       cycbuff->needflush = true;
       continue;
     }
