@@ -1,4 +1,4 @@
-/*  $Id: expire.c 10012 2016-05-05 12:41:10Z iulius $
+/*  $Id: expire.c 10413 2020-11-21 09:15:14Z iulius $
 **
 **  Code for overview-driven expiration.
 **
@@ -90,11 +90,11 @@ static ARTOVERFIELD *   ARTfields;
 static int              ARTfieldsize;
 static bool             ReadOverviewfmt = false;
 
+static char *           ACTIVE;
 
 /* FIXME: The following variables are shared between this file and ov.c.
    This should be cleaned up with a better internal interface. */
 time_t   OVnow;
-char *   ACTIVE;
 FILE *   EXPunlinkfile;
 bool     OVignoreselfexpire;
 bool     OVusepost;
