@@ -1,6 +1,6 @@
-#ifndef HAVE_DB_H
-# undef HAVE_BDB
-#endif
+/*  $Id: ovdb-private.h 10306 2018-12-02 14:26:13Z iulius $
+*/
+
 #ifdef HAVE_BDB
 
 #include <db.h>
