@@ -1,4 +1,4 @@
-/* $Id: ovdb.c 10306 2018-12-02 14:26:13Z iulius $
+/* $Id: ovdb.c 10513 2021-01-15 22:34:56Z iulius $
  *
  * ovdb.c
  * ovdb 2.00
@@ -2987,13 +2987,14 @@ ovdb_expiregroup(const char *group, int *lo, struct history *h)
 bool ovdb_ctl(OVCTLTYPE type, void *val)
 {
     int *i;
+    float *f;
     OVSORTTYPE *sorttype;
     bool *boolval;
 
     switch (type) {
     case OVSPACE:
-        i = (int *)val;
-        *i = -1;
+        f = (float *)val;
+        *f = -1.0f;
         return true;
     case OVSORT:
         sorttype = (OVSORTTYPE *)val;
