@@ -1,4 +1,4 @@
-/*  $Id: overview.c 9658 2014-08-28 18:59:18Z iulius $
+/*  $Id: overview.c 10513 2021-01-15 22:34:56Z iulius $
 **
 **  The implementation of the overview API.
 **
@@ -409,10 +409,10 @@ overview_config_set(struct overview *overview, struct overview_config *config)
 float
 overview_free_space(struct overview *overview)
 {
-    int space;
+    float space;
 
     if (overview->method->ctl(OVSPACE, &space))
         return space;
     else
-        return -1;
+        return -1.0f;
 }
