@@ -1,4 +1,4 @@
-/*  $Id: caf.c 10283 2018-05-14 12:43:05Z iulius $
+/*  $Id: caf.c 10342 2019-05-30 14:18:48Z iulius $
 **
 **  Library routines needed for handling CAF (Crunched Article Files)
 **  Written by Richard Todd (rmtodd@mailhost.ecn.uoknor.edu) 3/24/96,
@@ -687,7 +687,7 @@ CAFCreateCAFFile(char *cfpath, ARTNUM artnum, ARTNUM tocsize,
     }
 
     /* Initialize the header. */
-    strncpy(head.Magic, CAF_MAGIC, CAF_MAGIC_LEN);
+    memcpy(head.Magic, CAF_MAGIC, CAF_MAGIC_LEN);
     head.Low = artnum;
     head.High = artnum;
     head.NumSlots = tocsize;
