@@ -1,4 +1,4 @@
-/*  $Id: tradspool.c 9608 2014-02-17 19:12:15Z iulius $
+/*  $Id: tradspool.c 9841 2015-05-02 16:27:37Z iulius $
 **
 **  Storage manager module for traditional spool format.
 */
@@ -594,7 +594,8 @@ CrackXref(char *xref, unsigned int *lenp) {
 	    return xrefs;
 	}
 	/* skip to next space or EOL */
-	for (q=p; *q && *q != ' ' && *q != '\n' && *q != '\r' ; ++q) ;
+        for (q=p; *q && *q != ' ' && *q != '\n' && *q != '\r' ; ++q)
+            ;
 
         xrefs[len] = xstrndup(p, q - p);
 
