@@ -1,4 +1,4 @@
-/* $Id: fakeinnd.c 9242 2011-07-12 12:58:00Z iulius $ */
+/* $Id: fakeinnd.c 10263 2018-03-10 14:51:53Z iulius $ */
 /* Global symbols and tables required for innd-related files to link. */
 
 /* This file is required in order to test various portions of innd from
@@ -26,6 +26,7 @@ bool ThrottledbyIOError = false;
 bool BufferedLogs = true;
 FILE *Log = NULL;
 FILE *Errlog = NULL;
+bool laxmid = false;
 
 /* We have to copy this here.  Bleh.  We only need to care about headers up to
    message ID and Path, but they have to be in the same order as in innd.c and
@@ -107,7 +108,8 @@ const ARTHEADER ARTheaders[] = {
     ARTHEADERINIT("Archive",               HTstd),
     ARTHEADERINIT("Archived-At",           HTstd),
     ARTHEADERINIT("Summary",               HTstd),
-    ARTHEADERINIT("Comments",              HTstd)
+    ARTHEADERINIT("Comments",              HTstd),
+    ARTHEADERINIT("Jabber-ID",             HTstd),
 };
 
 /* Dummy functions that innd.c provides. */
