@@ -1,4 +1,4 @@
-/* $Id: getaddrinfo-t.c 10246 2018-02-16 21:12:42Z iulius $
+/* $Id: getaddrinfo-t.c 10396 2020-11-12 20:19:41Z iulius $
  *
  * getaddrinfo test suite.
  *
@@ -6,7 +6,7 @@
  * which can be found at <https://www.eyrie.org/~eagle/software/rra-c-util/>.
  *
  * Written by Russ Allbery <eagle@eyrie.org>
- * Copyright 2003-2005, 2016 Russ Allbery <eagle@eyrie.org>
+ * Copyright 2003-2005, 2016, 2019 Russ Allbery <eagle@eyrie.org>
  * Copyright 2015 Julien ÉLIE <julien@trigofacile.com>
  * Copyright 2007-2009, 2011-2013
  *     The Board of Trustees of the Leland Stanford Junior University
@@ -22,8 +22,8 @@
 #define LIBTEST_NEW_FORMAT 1
 
 #include "config.h"
-#include "clibrary.h"
 #include "portable/socket.h"
+#include "clibrary.h"
 
 #include "tap/basic.h"
 
@@ -33,12 +33,12 @@
  * implementation.
  */
 #if AI_NUMERICSERV == 0
-# undef AI_NUMERICSERV
-# define AI_NUMERICSERV 0x0080
+#    undef AI_NUMERICSERV
+#    define AI_NUMERICSERV 0x0080
 #endif
 #if AI_NUMERICHOST == 0
-# undef AI_NUMERICHOST
-# define AI_NUMERICHOST 0x0100
+#    undef AI_NUMERICHOST
+#    define AI_NUMERICHOST 0x0100
 #endif
 
 const char *test_gai_strerror(int);
@@ -108,8 +108,7 @@ main(void)
        "AI_NUMERICSERV with 25 smtp");
     ok(test_getaddrinfo(NULL, "25 ", &hints, &ai) == EAI_NONAME,
        "AI_NUMERICSERV with 25 space");
-    ok(test_getaddrinfo(NULL, "25", &hints, &ai) == 0,
-       "valid AI_NUMERICSERV");
+    ok(test_getaddrinfo(NULL, "25", &hints, &ai) == 0, "valid AI_NUMERICSERV");
     saddr = (struct sockaddr_in *) (void *) ai->ai_addr;
     is_int(htons(25), saddr->sin_port, "...right port");
     is_int(htonl(0x7f000001UL), saddr->sin_addr.s_addr, "...right address");
@@ -198,14 +197,14 @@ main(void)
     }
 
     /* Hopefully this will always resolve. */
-    host = gethostbyname("www.isc.org");
+    host = gethostbyname("www.eyrie.org");
     if (host == NULL)
-        skip_block(9, "cannot look up www.isc.org");
+        skip_block(9, "cannot look up www.eyrie.org");
     else {
         hints.ai_flags = 0;
         hints.ai_socktype = SOCK_STREAM;
-        ok(test_getaddrinfo("www.isc.org", "80", &hints, &ai) == 0,
-           "lookup of www.isc.org");
+        ok(test_getaddrinfo("www.eyrie.org", "80", &hints, &ai) == 0,
+           "lookup of www.eyrie.org");
         is_int(SOCK_STREAM, ai->ai_socktype, "...right socktype");
         is_string(NULL, ai->ai_canonname, "...no canonname");
         saddr = (struct sockaddr_in *) (void *) ai->ai_addr;
@@ -215,8 +214,8 @@ main(void)
         test_freeaddrinfo(ai);
 
         hints.ai_flags = AI_CANONNAME;
-        ok(test_getaddrinfo("www.isc.org", "80", &hints, &ai) == 0,
-           "lookup of www.isc.org with A_CANONNAME");
+        ok(test_getaddrinfo("www.eyrie.org", "80", &hints, &ai) == 0,
+           "lookup of www.eyrie.org with A_CANONNAME");
         ok(ai->ai_canonname != NULL, "...canonname isn't null");
         saddr = (struct sockaddr_in *) (void *) ai->ai_addr;
         is_int(htons(80), saddr->sin_port, "...right port");
