@@ -1,18 +1,19 @@
-/* $Id: hash-t.c 5623 2002-08-21 19:35:37Z alexk $ */
+/* $Id: hash-t.c 9669 2014-09-03 17:18:22Z iulius $ */
 /* hash test suite. */
 
 #include "config.h"
 #include "clibrary.h"
 
-#include "libinn.h"
-#include "libtest.h"
+#include "inn/libinn.h"
+#include "tap/basic.h"
 
 int
 main(void)
 {
     HASH h1, h2;
+    const char *text;
 
-    puts("12");
+    test_init(14);
 
     h1 = HashMessageID("<lhs@test.invalid>");
     h2 = HashMessageID("<lhs@TEST.invalid>");
@@ -43,5 +44,11 @@ main(void)
     h2 = HashMessageID("<POSTMASTER.test.invalid>");
     ok(12, HashCompare(&h1, &h2) != 0);
 
+    h1 = HashMessageID("<87is2w1u6i.fsf@windlord.stanford.edu>");
+    text = HashToText(h1);
+    ok_string(13, "A0D432DC9718979BEFB4ACADA4BAD863", text);
+    h2 = TextToHash("A0D432DC9718979BEFB4ACADA4BAD863");
+    ok(14, HashCompare(&h1, &h2) == 0);
+
     return 0;
 }
