@@ -1,4 +1,4 @@
-/* $Id: tst-t.c 9280 2011-07-17 19:36:24Z iulius $ */
+/* $Id: tst-t.c 10015 2016-05-05 12:43:09Z iulius $ */
 /* Test suite for ternary search tries. */
 
 #include "config.h"
@@ -7,10 +7,11 @@
 #include "inn/messages.h"
 #include "inn/tst.h"
 #include "inn/libinn.h"
-#include "libtest.h"
+#include "tap/basic.h"
 
-/* Used for strings of unsigned characters. */
-#define U (const unsigned char *)
+/* Used for strings of unsigned characters (called SUC instead of U
+   because it otherwise conflicts with Unicode strings). */
+#define SUC (const unsigned char *)
 
 /* An unsigned char version of strlen. */
 #define ustrlen(s) strlen((const char *) s)
@@ -30,44 +31,44 @@ main(void)
     char foo[] = "foo";
     char testing[] = "testing";
     char Strange[] = "Strange";
-    char change[] = "hange";
+    char change[] = "\231hange";
 
     test_init(38);
 
     tst = tst_init(2);
     ok(1, tst != NULL);
-    ok(2, tst_insert(tst, U"test", test, 0, NULL) == TST_OK);
-    ok_string(3, "test", tst_search(tst, U"test"));
-    ok(4, tst_insert(tst, U"test", foo, 0, &existing) == TST_DUPLICATE_KEY);
+    ok(2, tst_insert(tst, SUC"test", test, 0, NULL) == TST_OK);
+    ok_string(3, "test", tst_search(tst, SUC"test"));
+    ok(4, tst_insert(tst, SUC"test", foo, 0, &existing) == TST_DUPLICATE_KEY);
     ok_string(5, "test", existing);
-    ok(6, tst_insert(tst, U"test", foo, TST_REPLACE, &existing) == TST_OK);
+    ok(6, tst_insert(tst, SUC"test", foo, TST_REPLACE, &existing) == TST_OK);
     ok_string(7, "test", existing);
-    ok_string(8, "foo", tst_search(tst, U"test"));
-    ok(9, tst_insert(tst, U"testing", testing, 0, NULL) == TST_OK);
-    ok(10, tst_insert(tst, U"t", t, 0, NULL) == TST_OK);
-    ok(11, tst_insert(tst, U"Strange", Strange, 0, NULL) == TST_OK);
-    ok(12, tst_insert(tst, U"hange", change, 0, NULL) == TST_OK);
-    ok(13, tst_insert(tst, U"", foo, 0, NULL) == TST_NULL_KEY);
+    ok_string(8, "foo", tst_search(tst, SUC"test"));
+    ok(9, tst_insert(tst, SUC"testing", testing, 0, NULL) == TST_OK);
+    ok(10, tst_insert(tst, SUC"t", t, 0, NULL) == TST_OK);
+    ok(11, tst_insert(tst, SUC"Strange", Strange, 0, NULL) == TST_OK);
+    ok(12, tst_insert(tst, SUC"\231hange", change, 0, NULL) == TST_OK);
+    ok(13, tst_insert(tst, SUC"", foo, 0, NULL) == TST_NULL_KEY);
     ok(14, tst_insert(tst, NULL, foo, 0, NULL) == TST_NULL_KEY);
-    ok_string(15, "testing", tst_search(tst, U"testing"));
-    ok_string(16, "t", tst_search(tst, U"t"));
-    ok_string(17, "Strange", tst_search(tst, U"Strange"));
-    ok_string(18, "hange", tst_search(tst, U"hange"));
-    ok_string(19, "foo", tst_search(tst, U"test"));
-    ok(20, tst_search(tst, U"") == NULL);
-    ok(21, tst_search(tst, U"Peter") == NULL);
-    ok(22, tst_search(tst, U"foo") == NULL);
-    ok(23, tst_search(tst, U"te") == NULL);
-    ok_string(24, "Strange", tst_delete(tst, U"Strange"));
-    ok(25, tst_search(tst, U"Strange") == NULL);
-    ok_string(26, "t", tst_delete(tst, U"t"));
-    ok(27, tst_search(tst, U"t") == NULL);
-    ok_string(28, "testing", tst_search(tst, U"testing"));
-    ok_string(29, "foo", tst_search(tst, U"test"));
-    ok_string(30, "testing", tst_delete(tst, U"testing"));
-    ok_string(31, "foo", tst_search(tst, U"test"));
-    ok_string(32, "hange", tst_delete(tst, U"hange"));
-    ok_string(33, "foo", tst_delete(tst, U"test"));
+    ok_string(15, "testing", tst_search(tst, SUC"testing"));
+    ok_string(16, "t", tst_search(tst, SUC"t"));
+    ok_string(17, "Strange", tst_search(tst, SUC"Strange"));
+    ok_string(18, "\231hange", tst_search(tst, SUC"\231hange"));
+    ok_string(19, "foo", tst_search(tst, SUC"test"));
+    ok(20, tst_search(tst, SUC"") == NULL);
+    ok(21, tst_search(tst, SUC"Peter") == NULL);
+    ok(22, tst_search(tst, SUC"foo") == NULL);
+    ok(23, tst_search(tst, SUC"te") == NULL);
+    ok_string(24, "Strange", tst_delete(tst, SUC"Strange"));
+    ok(25, tst_search(tst, SUC"Strange") == NULL);
+    ok_string(26, "t", tst_delete(tst, SUC"t"));
+    ok(27, tst_search(tst, SUC"t") == NULL);
+    ok_string(28, "testing", tst_search(tst, SUC"testing"));
+    ok_string(29, "foo", tst_search(tst, SUC"test"));
+    ok_string(30, "testing", tst_delete(tst, SUC"testing"));
+    ok_string(31, "foo", tst_search(tst, SUC"test"));
+    ok_string(32, "\231hange", tst_delete(tst, SUC"\231hange"));
+    ok_string(33, "foo", tst_delete(tst, SUC"test"));
     ok(34, tst_search(tst, NULL) == NULL);
     ok(35, tst_delete(tst, NULL) == NULL);
     tst_cleanup(tst);
@@ -101,8 +102,10 @@ main(void)
     }
     ok(37, !reported);
 
-    if (fseek(words, 0, SEEK_SET) < 0)
+    if (fseek(words, 0, SEEK_SET) < 0) {
+        fclose(words);
         sysdie("Unable to rewind words file");
+    }
     reported = false;
     if (tst == NULL)
         reported = true;
@@ -129,6 +132,7 @@ main(void)
         }
     }
     tst_cleanup(tst);
+    fclose(words);
     ok(38, !reported);
 
     return 0;
