@@ -1,11 +1,11 @@
-/* $Id: xmalloc.c 10246 2018-02-16 21:12:42Z iulius $
+/* $Id: xmalloc.c 10396 2020-11-12 20:19:41Z iulius $
  *
  * Test suite for xmalloc and family.
  *
  * The canonical version of this file is maintained in the rra-c-util package,
  * which can be found at <https://www.eyrie.org/~eagle/software/rra-c-util/>.
  *
- * Copyright 2000-2001, 2006, 2017 Russ Allbery <eagle@eyrie.org>
+ * Copyright 2000-2001, 2006, 2017, 2020 Russ Allbery <eagle@eyrie.org>
  * Copyright 2008, 2012-2014
  *     The Board of Trustees of the Leland Stanford Junior University
  *
@@ -37,10 +37,11 @@
 #include "config.h"
 #include "clibrary.h"
 
+#include <assert.h>
 #include <ctype.h>
 #include <errno.h>
 #ifdef HAVE_SYS_TIME_H
-# include <sys/time.h>
+#    include <sys/time.h>
 #endif
 #include <time.h>
 
@@ -97,6 +98,7 @@ test_realloc(size_t size)
     char *buffer;
     size_t i;
 
+    assert(size > 10);
     buffer = xmalloc(10);
     if (buffer == NULL)
         return 0;
@@ -104,8 +106,7 @@ test_realloc(size_t size)
     buffer = xrealloc(buffer, size);
     if (buffer == NULL)
         return 0;
-    if (size > 0)
-        memset(buffer + 10, 2, size - 10);
+    memset(buffer + 10, 2, size - 10);
     for (i = 0; i < 10; i++)
         if (buffer[i] != 1)
             return 0;
@@ -386,6 +387,7 @@ main(int argc, char *argv[])
 #endif
     }
 
+    /* clang-format off */
     switch (code) {
     case 'c': exit(test_calloc(size) ? willfail : 1);
     case 'm': exit(test_malloc(size) ? willfail : 1);
@@ -397,5 +399,7 @@ main(int argc, char *argv[])
     case 'v': exit(test_vasprintf(size) ? willfail : 1);
     default:  die("Unknown mode %c", argv[1][0]);
     }
+    /* clang-format on */
+
     exit(1);
 }
