@@ -1,4 +1,4 @@
-/* $Id: innbind-t.c 9696 2014-09-20 06:17:39Z iulius $ */
+/* $Id: innbind-t.c 10308 2018-12-02 14:33:59Z iulius $ */
 /* innbind test suite. */
 
 #include "config.h"
@@ -317,7 +317,8 @@ main(void)
 
     if (access("innbind.t", F_OK) < 0)
         if (access("util/innbind.t", F_OK) == 0)
-            chdir("util");
+            if (chdir("util") < 0)
+                sysbail("cannot chdir to util");
 
     test_init(15);
 
